// Code generated by protoc-gen-go. DO NOT EDIT.
// source: middleware/cache/testdata/stream.proto

package testdata

import (
	context "context"
	fmt "fmt"
	proto "github.com/golang/protobuf/proto"
	gitalypb "gitlab.com/gitlab-org/gitaly/v14/proto/go/gitalypb"
	grpc "google.golang.org/grpc"
	codes "google.golang.org/grpc/codes"
	status "google.golang.org/grpc/status"
	math "math"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

type Request struct {
	Destination          *gitalypb.Repository `protobuf:"bytes,1,opt,name=destination,proto3" json:"destination,omitempty"`
	XXX_NoUnkeyedLiteral struct{}             `json:"-"`
	XXX_unrecognized     []byte               `json:"-"`
	XXX_sizecache        int32                `json:"-"`
}

func (m *Request) Reset()         { *m = Request{} }
func (m *Request) String() string { return proto.CompactTextString(m) }
func (*Request) ProtoMessage()    {}
func (*Request) Descriptor() ([]byte, []int) {
	return fileDescriptor_a8c7bc703e280c1d, []int{0}
}

func (m *Request) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_Request.Unmarshal(m, b)
}
func (m *Request) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_Request.Marshal(b, m, deterministic)
}
func (m *Request) XXX_Merge(src proto.Message) {
	xxx_messageInfo_Request.Merge(m, src)
}
func (m *Request) XXX_Size() int {
	return xxx_messageInfo_Request.Size(m)
}
func (m *Request) XXX_DiscardUnknown() {
	xxx_messageInfo_Request.DiscardUnknown(m)
}

var xxx_messageInfo_Request proto.InternalMessageInfo

func (m *Request) GetDestination() *gitalypb.Repository {
	if m != nil {
		return m.Destination
	}
	return nil
}

type Response struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *Response) Reset()         { *m = Response{} }
func (m *Response) String() string { return proto.CompactTextString(m) }
func (*Response) ProtoMessage()    {}
func (*Response) Descriptor() ([]byte, []int) {
	return fileDescriptor_a8c7bc703e280c1d, []int{1}
}

func (m *Response) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_Response.Unmarshal(m, b)
}
func (m *Response) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_Response.Marshal(b, m, deterministic)
}
func (m *Response) XXX_Merge(src proto.Message) {
	xxx_messageInfo_Response.Merge(m, src)
}
func (m *Response) XXX_Size() int {
	return xxx_messageInfo_Response.Size(m)
}
func (m *Response) XXX_DiscardUnknown() {
	xxx_messageInfo_Response.DiscardUnknown(m)
}

var xxx_messageInfo_Response proto.InternalMessageInfo

func init() {
	proto.RegisterType((*Request)(nil), "testdata.Request")
	proto.RegisterType((*Response)(nil), "testdata.Response")
}

func init() {
	proto.RegisterFile("middleware/cache/testdata/stream.proto", fileDescriptor_a8c7bc703e280c1d)
}

var fileDescriptor_a8c7bc703e280c1d = []byte{
	// 293 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x9c, 0x91, 0x41, 0x4a, 0xc3, 0x40,
	0x14, 0x86, 0x99, 0x52, 0x6a, 0x78, 0xd1, 0x85, 0xb3, 0xd0, 0x92, 0x95, 0x64, 0x21, 0x59, 0x48,
	0x52, 0x22, 0xb8, 0x70, 0xa7, 0x22, 0x5a, 0xa5, 0x9b, 0x54, 0x0f, 0x30, 0xce, 0x3c, 0x9a, 0x81,
	0x74, 0x26, 0xce, 0xbc, 0x2a, 0x39, 0x49, 0xbd, 0x8a, 0x17, 0xf0, 0x3c, 0xae, 0x5d, 0x89, 0x8d,
	0x91, 0xe2, 0x4a, 0xbb, 0x9c, 0x8f, 0xe1, 0xe3, 0xfb, 0x79, 0x70, 0x38, 0xd7, 0x4a, 0x55, 0xf8,
	0x2c, 0x1c, 0x66, 0x52, 0xc8, 0x12, 0x33, 0x42, 0x4f, 0x4a, 0x90, 0xc8, 0x3c, 0x39, 0x14, 0xf3,
	0xb4, 0x76, 0x96, 0x2c, 0x0f, 0x3a, 0x1c, 0x41, 0xa5, 0x0d, 0xb5, 0x34, 0xda, 0xf6, 0xa5, 0x70,
	0xa8, 0xda, 0x57, 0x7c, 0x09, 0x5b, 0x05, 0x3e, 0x2e, 0xd0, 0x13, 0x3f, 0x85, 0x50, 0xa1, 0x27,
	0x6d, 0x04, 0x69, 0x6b, 0x86, 0xec, 0x80, 0x25, 0x61, 0xce, 0xd3, 0x99, 0x26, 0x51, 0x35, 0x69,
	0x81, 0xb5, 0xf5, 0x9a, 0xac, 0x6b, 0xce, 0xfb, 0x2f, 0x6f, 0x47, 0xac, 0x58, 0xff, 0x1c, 0x03,
	0x04, 0x05, 0xfa, 0xda, 0x1a, 0x8f, 0x79, 0x01, 0x7c, 0x6c, 0x08, 0x9d, 0xc4, 0x9a, 0x50, 0x4d,
	0xd1, 0x3d, 0x69, 0x89, 0xfc, 0x04, 0x76, 0xc6, 0x33, 0x63, 0x1d, 0xaa, 0x09, 0x52, 0x69, 0x15,
	0xdf, 0x4d, 0xbb, 0xbc, 0xf4, 0xbb, 0x20, 0xe2, 0xeb, 0xa8, 0xb5, 0x45, 0xfd, 0xf7, 0x65, 0xc2,
	0xf2, 0xd7, 0x1e, 0x84, 0x77, 0xe8, 0xa9, 0xb3, 0xdd, 0xc0, 0xfe, 0x45, 0xa5, 0xd1, 0xd0, 0x74,
	0x35, 0xf8, 0x2b, 0x6e, 0xb2, 0x20, 0x41, 0xd6, 0xfd, 0xd1, 0x1b, 0x0f, 0x3e, 0x96, 0x49, 0x2f,
	0x60, 0x23, 0xc6, 0x6f, 0x61, 0xf8, 0xdb, 0x75, 0x26, 0x25, 0x7a, 0xff, 0x5f, 0x59, 0x6f, 0xc4,
	0xf8, 0x15, 0xec, 0xb5, 0xb2, 0x7b, 0x23, 0x5c, 0xb3, 0x79, 0x17, 0xbf, 0xee, 0x16, 0xfe, 0x88,
	0x36, 0x8c, 0x7a, 0x18, 0xac, 0x2e, 0x7d, 0xfc, 0x19, 0x00, 0x00, 0xff, 0xff, 0x34, 0xce, 0x60,
	0xcf, 0x37, 0x02, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// InterceptedServiceClient is the client API for InterceptedService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type InterceptedServiceClient interface {
	IgnoredMethod(ctx context.Context, in *Request, opts ...grpc.CallOption) (*Response, error)
}

type interceptedServiceClient struct {
	cc *grpc.ClientConn
}

func NewInterceptedServiceClient(cc *grpc.ClientConn) InterceptedServiceClient {
	return &interceptedServiceClient{cc}
}

func (c *interceptedServiceClient) IgnoredMethod(ctx context.Context, in *Request, opts ...grpc.CallOption) (*Response, error) {
	out := new(Response)
	err := c.cc.Invoke(ctx, "/testdata.InterceptedService/IgnoredMethod", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// InterceptedServiceServer is the server API for InterceptedService service.
type InterceptedServiceServer interface {
	IgnoredMethod(context.Context, *Request) (*Response, error)
}

// UnimplementedInterceptedServiceServer can be embedded to have forward compatible implementations.
type UnimplementedInterceptedServiceServer struct {
}

func (*UnimplementedInterceptedServiceServer) IgnoredMethod(ctx context.Context, req *Request) (*Response, error) {
	return nil, status.Errorf(codes.Unimplemented, "method IgnoredMethod not implemented")
}

func RegisterInterceptedServiceServer(s *grpc.Server, srv InterceptedServiceServer) {
	s.RegisterService(&_InterceptedService_serviceDesc, srv)
}

func _InterceptedService_IgnoredMethod_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(Request)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(InterceptedServiceServer).IgnoredMethod(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/testdata.InterceptedService/IgnoredMethod",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(InterceptedServiceServer).IgnoredMethod(ctx, req.(*Request))
	}
	return interceptor(ctx, in, info, handler)
}

var _InterceptedService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "testdata.InterceptedService",
	HandlerType: (*InterceptedServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "IgnoredMethod",
			Handler:    _InterceptedService_IgnoredMethod_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "middleware/cache/testdata/stream.proto",
}

// TestServiceClient is the client API for TestService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type TestServiceClient interface {
	ClientStreamRepoMutator(ctx context.Context, in *Request, opts ...grpc.CallOption) (TestService_ClientStreamRepoMutatorClient, error)
	ClientStreamRepoAccessor(ctx context.Context, in *Request, opts ...grpc.CallOption) (TestService_ClientStreamRepoAccessorClient, error)
	ClientUnaryRepoMutator(ctx context.Context, in *Request, opts ...grpc.CallOption) (*Response, error)
	ClientUnaryRepoAccessor(ctx context.Context, in *Request, opts ...grpc.CallOption) (*Response, error)
}

type testServiceClient struct {
	cc *grpc.ClientConn
}

func NewTestServiceClient(cc *grpc.ClientConn) TestServiceClient {
	return &testServiceClient{cc}
}

func (c *testServiceClient) ClientStreamRepoMutator(ctx context.Context, in *Request, opts ...grpc.CallOption) (TestService_ClientStreamRepoMutatorClient, error) {
	stream, err := c.cc.NewStream(ctx, &_TestService_serviceDesc.Streams[0], "/testdata.TestService/ClientStreamRepoMutator", opts...)
	if err != nil {
		return nil, err
	}
	x := &testServiceClientStreamRepoMutatorClient{stream}
	if err := x.ClientStream.SendMsg(in); err != nil {
		return nil, err
	}
	if err := x.ClientStream.CloseSend(); err != nil {
		return nil, err
	}
	return x, nil
}

type TestService_ClientStreamRepoMutatorClient interface {
	Recv() (*Response, error)
	grpc.ClientStream
}

type testServiceClientStreamRepoMutatorClient struct {
	grpc.ClientStream
}

func (x *testServiceClientStreamRepoMutatorClient) Recv() (*Response, error) {
	m := new(Response)
	if err := x.ClientStream.RecvMsg(m); err != nil {
		return nil, err
	}
	return m, nil
}

func (c *testServiceClient) ClientStreamRepoAccessor(ctx context.Context, in *Request, opts ...grpc.CallOption) (TestService_ClientStreamRepoAccessorClient, error) {
	stream, err := c.cc.NewStream(ctx, &_TestService_serviceDesc.Streams[1], "/testdata.TestService/ClientStreamRepoAccessor", opts...)
	if err != nil {
		return nil, err
	}
	x := &testServiceClientStreamRepoAccessorClient{stream}
	if err := x.ClientStream.SendMsg(in); err != nil {
		return nil, err
	}
	if err := x.ClientStream.CloseSend(); err != nil {
		return nil, err
	}
	return x, nil
}

type TestService_ClientStreamRepoAccessorClient interface {
	Recv() (*Response, error)
	grpc.ClientStream
}

type testServiceClientStreamRepoAccessorClient struct {
	grpc.ClientStream
}

func (x *testServiceClientStreamRepoAccessorClient) Recv() (*Response, error) {
	m := new(Response)
	if err := x.ClientStream.RecvMsg(m); err != nil {
		return nil, err
	}
	return m, nil
}

func (c *testServiceClient) ClientUnaryRepoMutator(ctx context.Context, in *Request, opts ...grpc.CallOption) (*Response, error) {
	out := new(Response)
	err := c.cc.Invoke(ctx, "/testdata.TestService/ClientUnaryRepoMutator", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *testServiceClient) ClientUnaryRepoAccessor(ctx context.Context, in *Request, opts ...grpc.CallOption) (*Response, error) {
	out := new(Response)
	err := c.cc.Invoke(ctx, "/testdata.TestService/ClientUnaryRepoAccessor", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// TestServiceServer is the server API for TestService service.
type TestServiceServer interface {
	ClientStreamRepoMutator(*Request, TestService_ClientStreamRepoMutatorServer) error
	ClientStreamRepoAccessor(*Request, TestService_ClientStreamRepoAccessorServer) error
	ClientUnaryRepoMutator(context.Context, *Request) (*Response, error)
	ClientUnaryRepoAccessor(context.Context, *Request) (*Response, error)
}

// UnimplementedTestServiceServer can be embedded to have forward compatible implementations.
type UnimplementedTestServiceServer struct {
}

func (*UnimplementedTestServiceServer) ClientStreamRepoMutator(req *Request, srv TestService_ClientStreamRepoMutatorServer) error {
	return status.Errorf(codes.Unimplemented, "method ClientStreamRepoMutator not implemented")
}
func (*UnimplementedTestServiceServer) ClientStreamRepoAccessor(req *Request, srv TestService_ClientStreamRepoAccessorServer) error {
	return status.Errorf(codes.Unimplemented, "method ClientStreamRepoAccessor not implemented")
}
func (*UnimplementedTestServiceServer) ClientUnaryRepoMutator(ctx context.Context, req *Request) (*Response, error) {
	return nil, status.Errorf(codes.Unimplemented, "method ClientUnaryRepoMutator not implemented")
}
func (*UnimplementedTestServiceServer) ClientUnaryRepoAccessor(ctx context.Context, req *Request) (*Response, error) {
	return nil, status.Errorf(codes.Unimplemented, "method ClientUnaryRepoAccessor not implemented")
}

func RegisterTestServiceServer(s *grpc.Server, srv TestServiceServer) {
	s.RegisterService(&_TestService_serviceDesc, srv)
}

func _TestService_ClientStreamRepoMutator_Handler(srv interface{}, stream grpc.ServerStream) error {
	m := new(Request)
	if err := stream.RecvMsg(m); err != nil {
		return err
	}
	return srv.(TestServiceServer).ClientStreamRepoMutator(m, &testServiceClientStreamRepoMutatorServer{stream})
}

type TestService_ClientStreamRepoMutatorServer interface {
	Send(*Response) error
	grpc.ServerStream
}

type testServiceClientStreamRepoMutatorServer struct {
	grpc.ServerStream
}

func (x *testServiceClientStreamRepoMutatorServer) Send(m *Response) error {
	return x.ServerStream.SendMsg(m)
}

func _TestService_ClientStreamRepoAccessor_Handler(srv interface{}, stream grpc.ServerStream) error {
	m := new(Request)
	if err := stream.RecvMsg(m); err != nil {
		return err
	}
	return srv.(TestServiceServer).ClientStreamRepoAccessor(m, &testServiceClientStreamRepoAccessorServer{stream})
}

type TestService_ClientStreamRepoAccessorServer interface {
	Send(*Response) error
	grpc.ServerStream
}

type testServiceClientStreamRepoAccessorServer struct {
	grpc.ServerStream
}

func (x *testServiceClientStreamRepoAccessorServer) Send(m *Response) error {
	return x.ServerStream.SendMsg(m)
}

func _TestService_ClientUnaryRepoMutator_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(Request)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(TestServiceServer).ClientUnaryRepoMutator(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/testdata.TestService/ClientUnaryRepoMutator",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(TestServiceServer).ClientUnaryRepoMutator(ctx, req.(*Request))
	}
	return interceptor(ctx, in, info, handler)
}

func _TestService_ClientUnaryRepoAccessor_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(Request)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(TestServiceServer).ClientUnaryRepoAccessor(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/testdata.TestService/ClientUnaryRepoAccessor",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(TestServiceServer).ClientUnaryRepoAccessor(ctx, req.(*Request))
	}
	return interceptor(ctx, in, info, handler)
}

var _TestService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "testdata.TestService",
	HandlerType: (*TestServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "ClientUnaryRepoMutator",
			Handler:    _TestService_ClientUnaryRepoMutator_Handler,
		},
		{
			MethodName: "ClientUnaryRepoAccessor",
			Handler:    _TestService_ClientUnaryRepoAccessor_Handler,
		},
	},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "ClientStreamRepoMutator",
			Handler:       _TestService_ClientStreamRepoMutator_Handler,
			ServerStreams: true,
		},
		{
			StreamName:    "ClientStreamRepoAccessor",
			Handler:       _TestService_ClientStreamRepoAccessor_Handler,
			ServerStreams: true,
		},
	},
	Metadata: "middleware/cache/testdata/stream.proto",
}
